# GetBillingPreviewRunResponse

get billingPreviewRun response

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**run_number** | **str** | The run number of the billing preview run.  | [optional] 
**assume_renewal** | **str** |  | [optional] 
**batch** | **str** | The customer batch included in the billing preview run.         **Note**: This field is not available if you set the &#x60;zuora-version&#x60; request header to &#x60;314.0&#x60; or later.  | [optional] 
**batches** | **str** | The customer batches included in the billing preview run.   **Note**: This field is only available if you set the &#x60;zuora-version&#x60; request header to &#x60;314.0&#x60; or later.  | [optional] 
**charge_type_to_exclude** | **str** | The charge types excluded from the forecast run.  | [optional] 
**created_by_id** | **str** | The ID of the user who created the billing preview run.  | [optional] 
**created_date** | **str** | The date and time when the billing preview run was created.  | [optional] 
**start_date** | **str** | The date and time when the billing preview run starts.  | [optional] 
**end_date** | **str** | The date and time when the billing preview run completes.  | [optional] 
**error_message** | **str** | The error message generated by a failed billing preview run.  | [optional] 
**including_draft_items** | **bool** | Whether draft document items are included in the billing preview run. By default, draft document items are not included.  | [optional] 
**including_evergreen_subscription** | **bool** | Indicates if evergreen subscriptions are included in the billing preview run.  | [optional] 
**result_file_url** | **str** | The URL of the zipped CSV result file generated by the billing preview run. This file contains the preview invoice item data and credit memo item data for the specified customers.  If the value of &#x60;storageOption&#x60; field is &#x60;Database&#x60;, the returned &#x60;resultFileUrl&#x60; field is null.  **Note:** The credit memo item data is only available if you have Invoice Settlement feature enabled. The Invoice Settlement feature is generally available as of Zuora Billing Release 296 (March 2021). This feature includes Unapplied Payments, Credit and Debit Memo, and Invoice Item Settlement. If you want to enable Invoice Settlement, see [Invoice Settlement Enablement and Checklist Guide](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/Invoice_Settlement_Migration_Checklist_and_Guide) for more information.  | [optional] 
**status** | **str** | The status of the &gt;billing preview run.  **Possible values:**   * 0: Pending * 1: Processing * 2: Completed * 3: Error * 4: Canceled  | [optional] 
**storage_option** | [**GetBillingPreviewRunResponseStorageOption**](GetBillingPreviewRunResponseStorageOption.md) |  | [optional] 
**succeeded_accounts** | **int** | The number of accounts for which preview invoice item data and credit memo item data was successfully generated during the billing preview run.  **Note:** The credit memo item data is only available if you have Invoice Settlement feature enabled. The Invoice Settlement feature is generally available as of Zuora Billing Release 296 (March 2021). This feature includes Unapplied Payments, Credit and Debit Memo, and Invoice Item Settlement. If you want to enable Invoice Settlement, see [Invoice Settlement Enablement and Checklist Guide](https://knowledgecenter.zuora.com/Billing/Billing_and_Payments/Invoice_Settlement/Invoice_Settlement_Migration_Checklist_and_Guide) for more information.  | [optional] 
**success** | **bool** | Returns &#x60;true&#x60; if the request was processed successfully. | [optional] 
**target_date** | **date** | The target date for the billing preview run.            | [optional] 
**total_accounts** | **int** | The total number of accounts in the billing preview run.  | [optional] 
**updated_by_id** | **str** | The ID of the user who last updated the billing preview run.  | [optional] 
**updated_date** | **str** | The date and time when the billing preview run was last updated.  | [optional] 

## Example

```python
from zuora_sdk.models.get_billing_preview_run_response import GetBillingPreviewRunResponse

# TODO update the JSON string below
json = "{}"
# create an instance of GetBillingPreviewRunResponse from a JSON string
get_billing_preview_run_response_instance = GetBillingPreviewRunResponse.from_json(json)
# print the JSON string representation of the object
print(GetBillingPreviewRunResponse.to_json())

# convert the object into a dict
get_billing_preview_run_response_dict = get_billing_preview_run_response_instance.to_dict()
# create an instance of GetBillingPreviewRunResponse from a dict
get_billing_preview_run_response_from_dict = GetBillingPreviewRunResponse.from_dict(get_billing_preview_run_response_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


